@@ -2,11 +2,11 @@
 # coding: utf-8
 
 # Autorship information
-__author__ = "Samuel Murail"
+__author__ = "Samuel Murail, Pierre Tuffery"
 __copyright__ = "Copyright 2020, RPBS"
 __credits__ = ["Samuel Murail"]
 __license__ = "GNU General Public License v2.0"
-__version__ = "1.3.10"
+__version__ = "1.4.1"
 __maintainer__ = "Samuel Murail"
 __email__ = "samuel.murail@u-paris.fr"
 __status__ = "Production"
