@@ -19,14 +19,14 @@ except ImportError:
     import pdb_manip
 
 # Autorship information
-__author__ = "Samuel Murail, Damien Espana, Pierre Tuffery"
+__author__ = "Samuel Murail, Pierre Tuffery"
 __copyright__ = "Copyright 2020, RPBS"
 __credits__ = ["Samuel Murail"]
 __license__ = "GNU General Public License v2.0"
 __version__ = "1.0.1"
 __maintainer__ = "Samuel Murail"
 __email__ = "samuel.murail@u-paris.fr"
-__status__ = "Prototype"
+__status__ = "Production"
 
 # Logging
 logger = logging.getLogger(__name__)
@@ -41,7 +41,7 @@ if on_rtd:
     PDB2PQR_BIN = ""
 else:
     # Add 'pdb2pqr_cli' in case it is installed with conda
-    PDB2PQR_BIN = os_command.which('pdb2pqr.py', 'pdb2pqr_cli')
+    PDB2PQR_BIN = os_command.which('pdb2pqr30')
     # PDB2PQR_BIN = os_command.which('pdb2pqr_cli')
 
 # Test folder path
@@ -83,8 +83,9 @@ def compute_pdb2pqr(pdb_in, pdb_out, ff="CHARMM",
     ... os.path.join(TEST_OUT, '4n1m.pqr')) #doctest: +ELLIPSIS
     Succeed to read file ...4n1m.pdb ,  2530 atoms found
     Succeed to save file ...tmp_pdb2pqr.pdb
-    pdb2pqr... --ff CHARMM --ffout CHARMM --chain --ph-calc-method=propka \
---with-ph=7.00 ...tmp_pdb2pqr.pdb ...4n1m.pqr
+    pdb2pqr30... --ff CHARMM --ffout CHARMM --keep-chain \
+--titration-state-method=propka --with-ph=7.00 \
+...tmp_pdb2pqr.pdb ...4n1m.pqr
     0
     >>> prot_coor = pdb_manip.Coor()
     >>> prot_coor.read_pdb(os.path.join(TEST_OUT, '4n1m.pqr'), \
@@ -126,16 +127,32 @@ pqr_format = True) #doctest: +ELLIPSIS
     tmp_coor = pdb_manip.Coor()
     tmp_coor.read_pdb(pdb_in)
 
+    # Remove Nucleic acids:
+    # WARNING, that part might be removed, as pdb2pqr could compute
+    # protonation on nucleic acid in a near future
+    na_index = tmp_coor.get_index_selection({'res_name': pdb_manip.NA_DICT})
+    tmp_coor.del_atom_index(index_list=na_index)
+
     # Remove HETATM
     no_hetatm_pdb = tmp_coor.select_part_dict({'field': 'ATOM'})
+    if no_hetatm_pdb.num == 0:
+        logger.warning('No amino acids present in pdb file'
+                       ', no PD2PQR calculation')
+        tmp_coor = pdb_manip.Coor()
+        tmp_coor.read_pdb(pdb_in)
+        # To be coherent with the pdb2pqr calc., remove HETATOM :
+        no_hetatm_pdb = tmp_coor.select_part_dict({'field': 'ATOM'})
+        no_hetatm_pdb.write_pqr(pdb_out)
+        return
+
     no_hetatm_pdb.write_pdb(os.path.join(out_folder + "/tmp_pdb2pqr.pdb"))
 
     cmd_pdb2pqr = os_command.Command(
         [PDB2PQR_BIN,
          "--ff", ff,
          "--ffout", ff,
-         "--chain",
-         "--ph-calc-method={}".format(method),
+         "--keep-chain",
+         "--titration-state-method={}".format(method),
          "--with-ph={:.2f}".format(ph),
          os.path.join(out_folder + "/tmp_pdb2pqr.pdb"),
          pdb_out])
